import { renderless as renderless$1, api as api$1 } from '@opentinyvue/vue-renderless/tree/vue';
import { defineComponent, directive, h, setup, isVue2, props } from '@opentinyvue/vue-common';
import { iconChevronRight, iconLoadingShadow, iconArrowBottom, iconEdit, iconDel, iconPlusSquare, iconFinish, iconExpand, iconPutAway, iconWarning, iconMarkOn } from '@opentinyvue/vue-icon';
import Switch from '@opentinyvue/vue-switch';
import Popover from '@opentinyvue/vue-popover';
import Button from '@opentinyvue/vue-button';
import Checkbox from '@opentinyvue/vue-checkbox';
import { Clickoutside, HighlightQuery } from '@opentinyvue/vue-directive';
import { renderless, api } from '@opentinyvue/vue-renderless/tree-node/vue';
import CollapseTransition from '@opentinyvue/vue-collapse-transition';
import Radio from '@opentinyvue/vue-radio';
import Input from '@opentinyvue/vue-input';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script$1 = defineComponent({
  name: "TreeNode",
  componentName: "TreeNode",
  directives: directive({
    Clickoutside
  }),
  inject: ["TreeRoot"],
  provide: function provide() {
    return {
      parentTree: this
    };
  },
  emits: ["update:modelValue", "node-expand", "radio-change", "tree-node-expand", "closeMenu"],
  props: {
    node: {
      default: function _default() {
        return {};
      }
    },
    props: {},
    expandIcon: Object,
    shrinkIcon: Object,
    expandIconColor: String,
    shrinkIconColor: String,
    renderContent: Function,
    renderAfterExpand: {
      type: Boolean,
      default: true
    },
    showCheckbox: {
      type: Boolean,
      default: false
    },
    showRadio: {
      type: Boolean,
      default: false
    },
    currentRadio: {
      type: Object,
      default: function _default2() {
        return {
          value: null
        };
      }
    },
    showNumber: {
      type: Boolean,
      default: false
    },
    collapsible: {
      type: Boolean,
      default: true
    },
    nodeHeight: Number,
    checkEasily: {
      type: Boolean,
      default: false
    },
    action: Object,
    nodeKey: String,
    theme: String,
    showCheckedMark: Boolean,
    showLine: Boolean,
    // tiny 新增，是否显示树节点聚焦时的背景颜色
    isShowFocusBg: {
      type: Boolean,
      default: true
    }
  },
  components: {
    CollapseTransition,
    TinyCheckbox: Checkbox,
    TinyRadio: Radio,
    TinyInput: Input,
    IconChevronRight: iconChevronRight(),
    IconLoading: iconLoadingShadow(),
    IconArrowBottom: iconArrowBottom(),
    IconEdit: iconEdit(),
    IconDel: iconDel(),
    IconPlusSquare: iconPlusSquare(),
    IconFinish: iconFinish(),
    IconExpand: iconExpand(),
    IconPutAway: iconPutAway(),
    MenuContext: {
      props: {
        node: {
          required: true
        }
      },
      render: function render() {
        var tree = this.$parent.state.tree;
        var data = this.node.data;
        return tree && tree.scopedSlots && tree.scopedSlots.contextmenu && tree.scopedSlots.contextmenu({
          data,
          node: this.node
        });
      }
    },
    NodeContent: {
      props: {
        node: {
          required: true
        },
        renderContent: Function
      },
      inject: ["TreeRoot", "parentTree"],
      render: function render2() {
        var parent = this.$parent;
        var tree = parent.state.tree;
        var node = this.node;
        var data = node.data, store = node.store;
        return this.renderContent ? this.renderContent(h, {
          _self: this,
          node,
          data,
          store
        }) : tree.scopedSlots.default && tree.scopedSlots.default({
          node,
          data
        }) || h("span", {
          class: "tiny-tree-node__label"
        }, node.label);
      }
    }
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      mono: true,
      extendOptions: {
        isVue2
      }
    });
  }
});
var render$1 = function render$12() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-tree-node__wrapper"
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.node.visible,
      expression: "node.visible"
    }],
    ref: "node",
    staticClass: "tiny-tree-node",
    class: {
      "is-indeterminate": !_vm.node.disabled && _vm.node.indeterminate,
      "is-current": _vm.node.isCurrent,
      "is-hidden": !_vm.node.visible,
      "is-checked": !_vm.node.disabled && _vm.node.checked,
      "is-focusable": !_vm.node.disabled,
      "is-expanded": _vm.state.expanded,
      "is-loading": _vm.node.loading,
      "is-disabled": _vm.node.disabled,
      "is-leaf": _vm.node.isLeaf,
      "is-root": _vm.node.level === 1,
      "is-show-focus-bg": _vm.isShowFocusBg,
      "show-line": _vm.showLine,
      "show-checkbox": _vm.showCheckbox
    },
    attrs: {
      "role": "treeitem",
      "tabindex": "-1",
      "aria-expanded": _vm.state.expanded,
      "aria-disabled": _vm.node.disabled,
      "aria-checked": _vm.node.checked,
      "draggable": _vm.state.tree.draggable
    },
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.handleClick.apply(null, arguments);
      },
      "contextmenu": function contextmenu($event) {
        $event.stopPropagation();
        return (function($event2) {
          return _vm.handleContextMenu($event2);
        }).apply(null, arguments);
      },
      "dragstart": function dragstart($event) {
        $event.stopPropagation();
        return _vm.handleDragStart.apply(null, arguments);
      },
      "dragover": function dragover($event) {
        $event.stopPropagation();
        return _vm.handleDragOver.apply(null, arguments);
      },
      "dragend": function dragend($event) {
        $event.stopPropagation();
        return _vm.handleDragEnd.apply(null, arguments);
      },
      "drop": function drop($event) {
        $event.stopPropagation();
        return _vm.handleDrop.apply(null, arguments);
      }
    }
  }, [_c("div", {
    ref: "content",
    class: {
      "tiny-tree-node__content": true,
      "tiny-tree-node__content-number": _vm.showNumber
    },
    style: {
      "height": _vm.nodeHeight ? _vm.nodeHeight + "px" : void 0,
      "line-height": _vm.nodeHeight ? _vm.nodeHeight + "px" : void 0
    },
    on: {
      "click": function click($event) {
        return _vm.handleContentClick(_vm.node, _vm.currentRadio);
      }
    }
  }, [_vm._l(_vm.showLine ? 1 : _vm.node.level - 1, function(i) {
    return _c("span", {
      key: i,
      staticClass: "tiny-tree-node__content-indent",
      style: {
        width: _vm.state.computedIndent,
        flexShrink: 0
      }
    });
  }), _c("div", {
    staticClass: "tiny-tree-node__content-left"
  }, [_vm.showNumber ? [_c("span", {
    staticClass: "tree-node-number"
  }, [_vm._v(_vm._s(_vm.node.data.number))])] : [_c("span", {
    class: ["tree-node-icon", {
      "is-disabled": _vm.node.disabled
    }],
    on: {
      "click": function click($event) {
        return _vm.handleExpandIconClick($event, _vm.node);
      }
    }
  }, [_vm.state.expandIcon !== void 0 && _vm.state.shrinkIcon !== void 0 ? [_c(_vm.state.expanded ? _vm.state.shrinkIcon : _vm.state.expandIcon, {
    tag: "component",
    class: ["tiny-tree-node__expand-icon", {
      "is-leaf": _vm.node.isLeaf
    }],
    attrs: {
      "fill": _vm.state.expanded ? _vm.state.shrinkIconColor : _vm.state.expandIconColor
    }
  })] : [_c(_vm.state.computedExpandIcon, {
    tag: "component",
    class: ["tiny-tree-node__expand-icon", {
      "is-leaf": _vm.node.isLeaf,
      expanded: !_vm.node.isLeaf && _vm.state.expanded,
      "is-saas-theme": _vm.state.isSaaSTheme
    }]
  })]], 2)], _vm.showCheckbox ? _c("tiny-checkbox", {
    ref: "checkbox",
    attrs: {
      "model-value": _vm.node.checked,
      "indeterminate": _vm.node.indeterminate,
      "disabled": !!_vm.node.disabled,
      "validate-event": false
    },
    on: {
      "change": _vm.handleCheckChange
    }
  }) : _vm._e(), _vm.showRadio ? _c("tiny-radio", {
    staticClass: "tiny-tree-node__content-left__radio",
    attrs: {
      "model-value": _vm.currentRadio.value,
      "validate-event": false,
      "label": _vm.node.id,
      "disabled": !!_vm.node.disabled
    },
    on: {
      "update:modelValue": function updateModelValue($event) {
        return _vm.$emit("radio-change", $event);
      }
    }
  }) : _vm._e(), _vm.node.loading ? _c("icon-loading", {
    staticClass: "tiny-tree-node__loading"
  }) : _vm._e(), _vm._t("prefix", null, {
    "node": _vm.node
  }), _vm.action.type === "edit" && _vm.action.node && _vm.action.node === _vm.node ? [_c("tiny-input", {
    ref: "editInput",
    staticClass: "tiny-tree-node__edit-input",
    attrs: {
      "autofocus": true,
      "clearable": ""
    },
    on: {
      "keyup": function keyup($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.saveEdit($event);
      },
      "blur": function blur($event) {
        return _vm.saveEdit($event);
      },
      "click": function click($event) {
        $event.stopPropagation();
        return (function($event2) {
          return $event2.stopPropagation();
        }).apply(null, arguments);
      }
    },
    model: {
      value: _vm.action.label,
      callback: function callback($$v) {
        _vm.$set(_vm.action, "label", $$v);
      },
      expression: "action.label"
    }
  })] : [_c("node-content", {
    attrs: {
      "node": _vm.node,
      "render-content": _vm.renderContent
    }
  })], _vm._t("suffix", null, {
    "node": _vm.node
  })], 2), _c("div", {
    class: ["tiny-tree-node__content-right", {
      "is-disabled": _vm.node.disabled
    }]
  }, [_vm.showCheckedMark && !_vm.showCheckbox && !_vm.node.disabled && _vm.node.isCurrent ? _c("span", {
    staticClass: "tiny-tree-node__checked-mark"
  }, [_c("icon-finish")], 1) : _vm._e(), _vm._t("operation", null, {
    "node": _vm.node
  }), _vm.action.show ? [_c("span", {
    attrs: {
      "title": _vm.t("ui.tree.edit")
    }
  }, [!_vm.action.editDisabled.includes(_vm.node.data[_vm.nodeKey]) ? _c("icon-edit", {
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.openEdit(_vm.node);
      }
    }
  }) : _vm._e()], 1), _c("span", {
    attrs: {
      "title": _vm.t("ui.tree.delete")
    }
  }, [!_vm.action.deleteDisabled.includes(_vm.node.data[_vm.nodeKey]) ? _c("icon-del", {
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.deleteNode($event, _vm.node);
      }
    }
  }) : _vm._e()], 1), _c("span", {
    attrs: {
      "title": _vm.t("ui.tree.newNodeTitle")
    }
  }, [!_vm.action.addDisabled.includes(_vm.node.data[_vm.nodeKey]) && _vm.node.data[_vm.state.props.label || "label"] ? _c("icon-plus-square", {
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.addNode(_vm.node);
      }
    }
  }) : _vm._e()], 1)] : _vm._e()], 2)], 2), _vm.node.childNodes.length ? [_c("collapse-transition", [!_vm.renderAfterExpand || _vm.state.childNodeRendered ? _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.expanded,
      expression: "state.expanded"
    }],
    staticClass: "tiny-tree-node__children",
    style: {
      "margin-left": _vm.showLine ? _vm.state.computedIndent : 0
    },
    attrs: {
      "role": "group",
      "aria-expanded": _vm.state.expanded
    }
  }, [_vm.showLine ? _c("span", {
    staticClass: "tiny-tree-node__children-indent",
    style: {
      width: _vm.state.computedIndent,
      left: "-" + _vm.state.computedIndent
    }
  }) : _vm._e(), _vm._l(_vm.state.renderedChildNodes, function(child) {
    return _c("tree-node", {
      key: _vm.getNodeKey(child),
      attrs: {
        "action": _vm.action,
        "show-radio": _vm.showRadio,
        "theme": _vm.theme,
        "is-show-focus-bg": _vm.isShowFocusBg,
        "current-radio": _vm.currentRadio,
        "render-content": _vm.renderContent,
        "expand-icon": _vm.state.expandIcon,
        "shrink-icon": _vm.state.shrinkIcon,
        "expand-icon-color": _vm.state.expandIconColor,
        "shrink-icon-color": _vm.state.shrinkIconColor,
        "render-after-expand": _vm.renderAfterExpand,
        "show-checkbox": _vm.showCheckbox,
        "show-number": _vm.showNumber,
        "node-height": _vm.nodeHeight,
        "show-checked-mark": _vm.showCheckedMark,
        "node-key": _vm.nodeKey,
        "check-easily": _vm.checkEasily,
        "node": child,
        "show-line": _vm.showLine
      },
      on: {
        "node-expand": _vm.handleChildNodeExpand,
        "radio-change": function radioChange($event) {
          return _vm.$emit("radio-change", $event);
        }
      },
      scopedSlots: _vm._u([{
        key: "prefix",
        fn: function fn(slotScoped) {
          return [_vm._t("prefix", null, {
            "node": slotScoped.node
          })];
        }
      }, {
        key: "suffix",
        fn: function fn(slotScoped) {
          return [_vm._t("suffix", null, {
            "node": slotScoped.node
          })];
        }
      }, {
        key: "operation",
        fn: function fn(slotScoped) {
          return [_vm._t("operation", null, {
            "node": slotScoped.node
          })];
        }
      }], null, true)
    });
  })], 2) : _vm._e()])] : _vm._e()], 2), _vm.state.showMenu && _vm.TreeRoot.showContextmenu ? _c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.closeMenu,
      expression: "closeMenu"
    }],
    ref: "menuContext",
    staticClass: "tiny-tree-node__menu",
    style: _vm.state.menuposition,
    on: {
      "contextmenu": function contextmenu($event) {
        $event.stopPropagation();
      },
      "click": function click($event) {
        $event.stopPropagation();
      }
    }
  }, [_c("menu-context", {
    attrs: {
      "node": _vm.node
    }
  })], 1) : _vm._e()]);
};
var staticRenderFns$1 = [];
var __cssModules$1 = {};
var __component__$1 = /* @__PURE__ */ normalizeComponent(__vue2_script$1, render$1, staticRenderFns$1, false, __vue2_injectStyles$1);
function __vue2_injectStyles$1(context) {
  for (var o in __cssModules$1) {
    this[o] = __cssModules$1[o];
  }
}
var TreeNode = /* @__PURE__ */ function() {
  return __component__$1.exports;
}();
var __vue2_script = defineComponent({
  directives: _extends({}, directive({
    Clickoutside
  }), {
    HighlightQuery
  }),
  props: [].concat(props, ["data", "dataset", "parentKey", "expandIcon", "shrinkIcon", "expandIconColor", "shrinkIconColor", "emptyText", "renderAfterExpand", "nodeKey", "checkStrictly", "defaultExpandAll", "expandOnClickNode", "checkOnClickNode", "checkDescendants", "autoExpandParent", "defaultCheckedKeys", "defaultExpandedKeys", "defaultExpandedKeysHighlight", "currentNodeKey", "renderContent", "showCheckbox", "draggable", "allowDrag", "allowDrop", "props", "lazy", "highlightCurrent", "load", "filterNodeMethod", "accordion", "indent", "icon", "iconTriggerClickNode", "showRadio", "showContextmenu", "showNumber", "collapsible", "nodeHeight", "showCheckEasily", "size", "deleteDisabledKeys", "editDisabledKeys", "addDisabledKeys", "theme", "viewType", "showAuxi", "pathSplit", "filterPlainMethod", "afterLoad", "lazyCurrent", "baseIndent", "showLine", "onlyCheckChildren", "deleteNodeMethod", "showCheckedMark", "willChangeView", "editConfig", "isShowFocusBg", "highlightQuery"]),
  components: {
    TreeNode,
    IconWarning: iconWarning(),
    IconMarkOn: iconMarkOn(),
    TinyPopover: Popover,
    TinyCheckbox: Checkbox,
    TinyButton: Button,
    TinySwitch: Switch,
    TinyRadio: Radio
  },
  emits: ["node-expand", "check-change", "check", "node-drag-over", "node-drag-enter", "node-drag-leave", "node-drag-start", "node-drag-end", "node-drop", "current-change", "node-click", "leave-plain-view", "check-plain", "load-data", "open-edit", "close-edit", "save-edit", "add-node", "edit-node", "delete-node", "closeMenu"],
  provide: function provide2() {
    return {
      parentTree: this,
      TreeRoot: this
    };
  },
  setup: function setup2(props2, context) {
    return setup({
      props: props2,
      context,
      renderless: renderless$1,
      api: api$1,
      extendOptions: {
        isVue2
      }
    });
  }
});
var render3 = function render4() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-tree",
    class: {
      "tiny-tree--highlight-current": _vm.highlightCurrent,
      "is-dragging": !!_vm.state.dragState.draggingNode,
      "is-drop-not-allow": !_vm.state.dragState.allowDrop,
      "is-drop-inner": _vm.state.dragState.dropType === "inner",
      "tiny-tree--small": _vm.size === "small"
    },
    attrs: {
      "role": "tree"
    }
  }, [_vm.viewType === "tree" ? _vm._l(_vm.state.renderedChildNodes, function(child) {
    return _c("tree-node", {
      directives: [{
        name: "highlight-query",
        rawName: "v-highlight-query",
        value: _vm.highlightQuery ? _vm.state.filterText : "",
        expression: "highlightQuery ? state.filterText : ''"
      }],
      key: _vm.getNodeKey(child),
      attrs: {
        "action": _vm.state.action,
        "show-radio": _vm.showRadio,
        "theme": _vm.theme,
        "show-number": _vm.showNumber,
        "is-show-focus-bg": _vm.isShowFocusBg,
        "collapsible": _vm.collapsible,
        "node-height": _vm.nodeHeight,
        "current-radio": _vm.state.currentRadio,
        "expand-icon": _vm.expandIcon,
        "shrink-icon": _vm.shrinkIcon,
        "expand-icon-color": _vm.expandIconColor,
        "shrink-icon-color": _vm.shrinkIconColor,
        "node": child,
        "props": _vm.props,
        "render-after-expand": _vm.renderAfterExpand,
        "show-checkbox": _vm.showCheckbox,
        "node-key": _vm.nodeKey,
        "render-content": _vm.renderContent,
        "check-easily": _vm.state.checkEasily,
        "show-line": _vm.showLine,
        "show-checked-mark": _vm.showCheckedMark
      },
      on: {
        "radio-change": function radioChange($event) {
          _vm.state.currentRadio.value = $event;
        },
        "node-expand": _vm.handleNodeExpand
      },
      scopedSlots: _vm._u([{
        key: "prefix",
        fn: function fn(slotScoped) {
          return [_vm._t("prefix", null, {
            "node": slotScoped.node
          })];
        }
      }, {
        key: "suffix",
        fn: function fn(slotScoped) {
          return [_vm._t("suffix", null, {
            "node": slotScoped.node
          })];
        }
      }, {
        key: "operation",
        fn: function fn(slotScoped) {
          return [_vm._t("operation", null, {
            "node": slotScoped.node
          })];
        }
      }], null, true)
    });
  }) : _vm.viewType === "plain" ? _vm._l(_vm.state.plainNodeStore.filteredNodes, function(plainNode, i) {
    return _c("div", {
      key: plainNode.nodeKeyPath + "-" + i,
      staticClass: "tiny-tree__plain-node"
    }, [_c("div", {
      staticClass: "tiny-tree__plain-node-title"
    }, [_vm.showCheckbox ? _c("tiny-checkbox", {
      attrs: {
        "model-value": plainNode.node.checked,
        "indeterminate": plainNode.node.indeterminate,
        "disabled": !!plainNode.node.disabled
      },
      on: {
        "change": function change($event) {
          return _vm.handleCheckPlainNode($event, plainNode);
        }
      }
    }) : _vm._e(), _vm.showRadio ? _c("tiny-radio", {
      attrs: {
        "validate-event": false,
        "label": plainNode.node.id,
        "disabled": !!plainNode.node.disabled
      },
      on: {
        "change": function change($event) {
          return _vm.handleCheckPlainNode($event === plainNode.node.id, plainNode);
        }
      },
      model: {
        value: _vm.state.currentRadio.value,
        callback: function callback($$v) {
          _vm.$set(_vm.state.currentRadio, "value", $$v);
        },
        expression: "state.currentRadio.value"
      }
    }) : _vm._e(), _vm._t("prefix", null, {
      "node": plainNode.node
    }), _vm._t("default", function() {
      return [_c("span", {
        directives: [{
          name: "highlight-query",
          rawName: "v-highlight-query",
          value: _vm.highlightQuery ? _vm.state.filterText : "",
          expression: "highlightQuery ? state.filterText : ''"
        }],
        staticClass: "tiny-tree__plain-node-title-txt"
      }, [_vm._v(_vm._s(plainNode.title))])];
    }, {
      "node": plainNode.node
    }), _vm._t("suffix", function() {
      return [_c("span", {
        staticClass: "tiny-tree__plain-node-title-loc"
      }, [_c("icon-mark-on", {
        on: {
          "click": function click($event) {
            return _vm.handleClickPlainNode($event, plainNode);
          }
        }
      })], 1)];
    }, {
      "node": plainNode.node
    })], 2), _vm.showAuxi && plainNode.auxi ? _c("div", {
      staticClass: "tiny-tree__plain-node-auxi"
    }, [_c("div", [_vm._v(_vm._s(plainNode.auxi))])]) : _vm._e()]);
  }) : _vm._e(), _vm.state.isEmpty ? _c("div", {
    staticClass: "tiny-tree__empty-block"
  }, [_vm._t("empty", function() {
    return [_c("span", {
      staticClass: "tiny-tree__empty-text"
    }, [_vm._v(_vm._s(_vm.state.loaded ? _vm.state.showEmptyText : _vm.t("ui.tree.loading")))])];
  })], 2) : _vm._e(), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.dragState.showDropIndicator,
      expression: "state.dragState.showDropIndicator"
    }],
    ref: "dropIndicator",
    staticClass: "tiny-tree__drop-indicator"
  }), _vm.state.store.checkStrictly && _vm.showCheckEasily ? _c("div", {
    staticClass: "tiny-tree__strict-bottom"
  }, [_c("div", {
    staticClass: "tiny-tree__strict-bottom-content"
  }, [_c("tiny-switch", {
    attrs: {
      "mini": ""
    },
    on: {
      "change": _vm.switchToggle
    },
    model: {
      value: _vm.state.checkEasily,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "checkEasily", $$v);
      },
      expression: "state.checkEasily"
    }
  }), _c("div", {
    staticClass: "tiny-tree__bottom-text"
  }, [_vm._t("switchText", function() {
    return [_c("span", [_vm._v(_vm._s(_vm.t("ui.tree.switchText")))])];
  })], 2)], 1)]) : _vm._e(), _vm.state.action.show ? _c("tiny-popover", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.action.popoverVisible,
      expression: "state.action.popoverVisible"
    }],
    ref: "deletePopover",
    attrs: {
      "popper-class": "tiny-tree__del-popover",
      "placement": "top",
      "width": _vm.state.action.isLeaf ? 200 : 270,
      "trigger": "manual",
      "reference": _vm.state.action.referenceElm
    },
    model: {
      value: _vm.state.action.popoverVisible,
      callback: function callback($$v) {
        _vm.$set(_vm.state.action, "popoverVisible", $$v);
      },
      expression: "state.action.popoverVisible"
    }
  }, [_c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.cancelDelete,
      expression: "cancelDelete"
    }],
    staticClass: "tiny-tree__del-body"
  }, [_c("div", {
    staticClass: "tiny-tree__del-icon"
  }, [_c("icon-warning")], 1), _c("div", {
    staticClass: "tiny-tree__del-content"
  }, [_vm.state.action.isLeaf ? [_c("div", [_vm._v(_vm._s(_vm.t("ui.tree.deleteTip1")))])] : [_c("div", [_vm._v(_vm._s(_vm.t("ui.tree.deleteTip2")))]), _c("div", {
    staticClass: "tiny-tree__del-checkbox"
  }, [_c("tiny-checkbox", {
    ref: "deleteCheckbox",
    model: {
      value: _vm.state.action.isSaveChildNode,
      callback: function callback($$v) {
        _vm.$set(_vm.state.action, "isSaveChildNode", $$v);
      },
      expression: "state.action.isSaveChildNode"
    }
  }, [_vm._v(_vm._s(_vm.t("ui.tree.deleteTip3")))])], 1)]], 2)]), _c("div", {
    staticClass: "tiny-tree__del-footer"
  }, [_c("tiny-button", {
    attrs: {
      "size": "mini"
    },
    on: {
      "click": _vm.cancelDelete
    }
  }, [_vm._v(_vm._s(_vm.t("ui.base.cancel")))]), _c("tiny-button", {
    attrs: {
      "type": "primary",
      "size": "mini"
    },
    on: {
      "click": _vm.deleteAction
    }
  }, [_vm._v(_vm._s(_vm.t("ui.base.confirm")))])], 1)]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render3, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
